@@ -18,11 +18,11 @@ try:
         node_name="logger-producer",
         app_name="logger producer",
         worker_queue_name="logger",
-        broker_url=config.broker_url,
-        result_backend=config.result_backend,
+        broker_url=config.broker.url,
+        result_backend=config.result_backend.url,
     )
 
-    if config.sentinel_mode:
+    if config.result_backend.sentinel_mode:
         worker.conf.result_backend_transport_options = {"master_name": "redismaster"}
 
 except Exception:
